@@ -30,9 +30,9 @@
 
 G_BEGIN_DECLS
 
-void cria_presentation_populate_from_xml_input (CriaPresentation* self,
-						GsfInput        * input,
-						GError		**error);
+CriaPresentation* cria_presentation_populate_from_xml_input(GsfInput        * input,
+							    GnomeVFSURI     * uri,
+							    GError	    **error);
 
 G_END_DECLS
 
