@@ -32,21 +32,22 @@ typedef struct _CriaTheme		CriaTheme;
 typedef struct _CriaThemeClass		CriaThemeClass;
 typedef struct _CriaThemePrivate	CriaThemePrivate;
 
-#include "slide.h"
+#include <dom/cria-slide.h>
 
-void		cria_theme_add_master_slide    (CriaTheme	* self,
+void		  cria_theme_add_master_slide  (CriaTheme	* self,
 						CriaSlide	* master_slide);
-CriaSlide*	cria_theme_get_master_slide    (CriaTheme	* self,
+CriaSlide*	  cria_theme_get_master_slide  (CriaTheme	* self,
 						const char	* master_slide);
-GType		cria_theme_get_type	       (void);
-const gchar*	cria_theme_get_name	       (CriaTheme	* self);
-CriaTheme*	cria_theme_new		       (const char	* name);
-void		cria_theme_set_name	       (CriaTheme	* self,
+GType		  cria_theme_get_type	       (void);
+const gchar*	  cria_theme_get_name	       (CriaTheme	* self);
+CriaTheme*	  cria_theme_new	       (const char	* name);
+void		  cria_theme_set_name	       (CriaTheme	* self,
 						const char	* attribute);
+GHashTable*       cria_theme_get_master_slides (CriaTheme	* self);
 
 #define CRIA_TYPE_THEME			(cria_theme_get_type ())
 #define CRIA_THEME(object)		(G_TYPE_CHECK_INSTANCE_CAST((object), CRIA_TYPE_THEME, CriaTheme))
-#define CRIA_THEME_CLASS(klass)		(G_TYPE_CHACK_CLASS_CAST((klass), CRIA_TYPE_THEME, CriaThemeClass))
+#define CRIA_THEME_CLASS(klass)		(G_TYPE_CHECK_CLASS_CAST((klass), CRIA_TYPE_THEME, CriaThemeClass))
 #define CRIA_IS_THEME(object)		(G_TYPE_CHECK_INSTANCE_TYPE((object), CRIA_TYPE_THEME))
 #define CRIA_IS_THEME_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), CRIA_TYPE_THEME))
 #define CRIA_THEME_GET_CLASS(object)	(G_TYPE_INSTANCE_GET_CLASS((object), CRIA_TYPE_THEME, CriaThemeClass))
